/**

 * original author: Husamuldeen <https://github.com/hussamaldean>

   ----------------------------------------------------------------------
   	Copyright (C) husamuldeen, 2020


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
   ----------------------------------------------------------------------
 */

#ifndef SPI1_H_
#define SPI1_H_

#include "stdint.h"


/*
 * @brief This function will initialize SPI1 related pins.
 * @return nothing.
 * @see Pinout of datasheet for SPI pins.
 * */
void SPI1_Pins_Init(void);


/*
 * @brief This function will initialize CS pin .
 * @return nothing.
 * */
void W25QXX_CS_Pins_Init(void);

/*
 * @brief This function will initialize SPI1
 * and configure it.
 * @return nothing.
 * @see reference manual SPI section.
 * */
void SPI1_Config(void);

/*
 * @brief This function will transmit data over SPI bus.
 * @param *data pointer to the data to be written.
 * @param size  size of the data to be written.
 * @return nothing.
 * */
void SPI1_Transmit(uint8_t *data,uint32_t size);

/*
 * @brief This function will read data from SPI bus.
 * @param *data pointer to the data to be read.
 * @param size  size of the data to be read.
 * @return nothing.
 * */
void SPI1_Receive(uint8_t *data,uint32_t size);

/*
 * @brief This function will set CS pin to Low .
 * @return nothing.
 * */
void W25QXX_CS_LOW(void);

/*
 * @brief This function will set CS pin to High.
 * @return nothing.
 * */
void W25QXX_CS_HIGH(void);

#endif /* SPI1_H_ */
